@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Session::Handler::Role;
-$Web::Authenticate::Session::Handler::Role::VERSION = '0.005';
+$Web::Authenticate::Session::Handler::Role::VERSION = '0.011';
 use Mouse::Role;
 #ABSTRACT: A Mouse::Role that defines what methods a Web::Authenticate::Session::Handler object should contain.
 
@@ -14,6 +14,9 @@ requires 'delete_session';
 requires 'update_expires';
 
 
+requires 'invalidate_current_session';
+
+
 requires 'invalidate_user_sessions';
 
 
@@ -33,7 +36,7 @@ Web::Authenticate::Session::Handler::Role - A Mouse::Role that defines what meth
 
 =head1 VERSION
 
-version 0.005
+version 0.011
 
 =head1 METHODS
 
@@ -55,6 +58,12 @@ Updates the expires time for session. Returns an object that does L<Web::Authent
 
     my $updated_session = $session_handler->update_expires($session);
 
+=head2 invalidate_current_session
+
+Invalidates the current session if the user has one.
+
+    $session_handler->invalidate_current_session;
+
 =head2 invalidate_user_sessions
 
 Invalidates all sessions for a user.
